@@ -113,11 +113,9 @@ impl Parse for Catch {
         }
         let error: Ident = input.parse()?;
         let err_type = if input.peek(Token![:]) {
-            eprintln!("Yes colon\n\n\n\n");
             let _colon: Token![:] = input.parse()?;
             Some(input.parse()?)
         } else {
-            eprintln!("No colon\n\n\n\n");
             None
         };
         let block = parse_block(&input)?;
